#!/bin/bash -l
#SBATCH --job-name="Na-Liq-7b"
#SBATCH --time=1-00:00:00
#SBATCH --account=mr22
#SBATCH --exclusive
#SBATCH --nodes=1
#SBATCH --ntasks-per-node=10
#SBATCH --ntasks-per-core=1
#SBATCH --cpus-per-task=1
#SBATCH --constraint=mc
#========================================

############################################################################
# Variables definition
############################################################################
LAMMPS_HOME=/users/piaggip/bin/DAINT/LAMMPS/lammps-19May17/src
LAMMPS_RUN=${LAMMPS_HOME}/lmp_gnu-xc30
cycles=2
############################################################################

############################################################################
# Run
############################################################################
if [ -e runno ] ; then
   #########################################################################
   # Restart runs
   #########################################################################
   nn=`tail -n 1 runno | awk '{print $1}'`
   srun -n $SLURM_NTASKS -c $SLURM_CPUS_PER_TASK ${LAMMPS_RUN} < Restart.lmp &> log.lammps
   #########################################################################
else
   #########################################################################
   # First run
   #########################################################################
   nn=1
   # Number of partitions
   srun -n $SLURM_NTASKS -c $SLURM_CPUS_PER_TASK ${LAMMPS_RUN} < start.lmp &> log.lammps
   #########################################################################
fi
############################################################################

############################################################################
# Prepare next run
############################################################################
# Back up
#cp dump.${j} dump.${j}.${nn}
cp log.lammps log.lammps.${nn}
cp restart2.lmp restart2.lmp.${nn}
cp restart.lmp restart.lmp.${nn}
cp data.final data.final.${nn}
# Prepare new initial coefficients
#tail -n 239 coeffs > initCoeffs.dat
############################################################################

############################################################################
# Check number of cycles
############################################################################
mm=$((nn+1))
echo ${mm} > runno
#cheking number of cycles
if [ ${nn} -ge ${cycles} ]; then
  exit
fi
############################################################################

############################################################################
# Resubmitting again
############################################################################
sbatch < job.sh
############################################################################

